@@ -1,4 +1,3 @@
-
 #-*- coding:utf-8 -*-
 
 """
@@ -34,108 +33,110 @@ class experiment(item.item):
 
 	"""The main experiment class, which is the first item to be called"""
 
-	def __init__(self, name='experiment', string=None, pool_folder=None):
+	def __init__(self, name=u'experiment', string=None, pool_folder=None):
 
 		"""<DOC>
 		Constructor. The experiment is created automatically be OpenSesame and #
 		you will generally not need to create it yourself.
 
 		Keyword arguments:
-		name -- The name of the experiment (default='experiment').
-		string -- A string containing the experiment definition (default=None).
-		pool_folder -- A specific folder to be used for the file pool #
-					   (default=None).
+		name 		--	The name of the experiment. (default='experiment')
+		string 		--	A string containing the experiment definition. #
+						(default=None)
+		pool_folder	--	A specific folder to be used for the file pool. #
+						(default=None)
 		</DOC>"""
 
 		global pool_folders
-		
+
 		self.items = {}
 		self.running = False
 		self.auto_response = False
-		self.plugin_folder = "plugins"
+		self.plugin_folder = u'plugins'
 		self.start_response_interval = None
 		self.cleanup_functions = []
 		self.restart = False
 		self.experiment_path = None
-		self.title = 'My Experiment'
+		self.title = u'My Experiment'
+		self.transparent_variables = u'no'
 
 		# Set default variables
-		self.coordinates = "relative"
-		self.compensation = 0
-		self.start = "experiment"
-		
+		self.coordinates = u'relative' # DEPRECATED
+		self.compensation = 0 # DEPRECATED
+		self.start = u'experiment'
+
 		# Sound parameters
 		self.sound_freq = 48000
-		self.sound_sample_size = -16 # Negative values means signed
+		self.sound_sample_size = -16 # Negative values mean signed
 		self.sound_channels = 2
 		self.sound_buf_size = 512
 		self.resources = {}
 
 		# Backend parameters
-		self.canvas_backend = "xpyriment"
-		self.keyboard_backend = "legacy"
-		self.mouse_backend = "xpyriment"
-		self.sampler_backend = "legacy"
-		self.synth_backend = "legacy"
+		self.canvas_backend = u'xpyriment'
+		self.keyboard_backend = u'legacy'
+		self.mouse_backend = u'xpyriment'
+		self.sampler_backend = u'legacy'
+		self.synth_backend = u'legacy'
 
 		# Display parameters
 		self.width = 1024
 		self.height = 768
-		self.background = "black"
-		self.foreground = "white"		
+		self.background = u'black'
+		self.foreground = u'white'
 		self.fullscreen = False
 
 		# Font parameters
 		self.font_size = 18
-		self.font_family = "mono"
-		self.font_italic = "no"
-		self.font_bold = "no"
-		self.font_underline = "no"
+		self.font_family = u'mono'
+		self.font_italic = u'no'
+		self.font_bold = u'no'
+		self.font_underline = u'no'
 
 		# Logfile parameters
 		self._log = None
 		self.logfile = None
-		
-		# This is a dummy variable for backwards compatibility. The logfile 
+
+		# This is a dummy variable for backwards compatibility. The logfile
 		# encoding is always utf-8, and this variable doesn't do anything.
-		self.logfile_codec = "utf-8"	
-		
+		self.logfile_codec = u'utf-8'
+
 		# Default subject info
 		self.subject_nr = 0
-		self.subject_parity = "even"				
+		self.subject_parity = u'even'
 
 		# This is some duplication of the option parser in qtopensesame,
 		# but nevertheless keep it so we don't need qtopensesame
-		self.debug = "--debug" in sys.argv or "-d" in sys.argv
-		self._stack = "--stack" in sys.argv or "-s" in sys.argv
+		self.debug = debug.enabled
+		self._stack = debug.stack
 
 		# Pool folder
 		if pool_folder == None:
-			self.pool_folder = tempfile.mkdtemp(".opensesame_pool")
+			self.pool_folder = tempfile.mkdtemp(u'.opensesame_pool')
 			pool_folders.append(self.pool_folder)
-			debug.msg("creating new pool folder")
+			debug.msg(u'creating new pool folder')
 		else:
-			debug.msg("reusing existing pool folder")
+			debug.msg(u'reusing existing pool folder')
 			self.pool_folder = pool_folder
-		debug.msg("pool folder is '%s'" % self.pool_folder)
-		
+		debug.msg(u'pool folder is \'%s\'' % self.pool_folder)
+
 		string = self.open(string)
 		item.item.__init__(self, name, self, string)
-		
+
 	def module_container(self):
 
 		"""Specify the module that contains the item modules"""
 
-		return "libopensesame"
+		return u'libopensesame'
 
 	def item_prefix(self):
 
 		"""
 		A prefix for the plug-in classes, so that [prefix][plugin] class is used
-		instead of the [plugin] class
+		instead of the [plugin] class.
 		"""
 
-		return ""
+		return u''
 
 	def set_subject(self, nr):
 
@@ -145,8 +146,8 @@ class experiment(item.item):
 		generally need to call it yourself.
 
 		Arguments:
-		nr -- The subject nr.
-		
+		nr	--	The subject nr.
+
 		Example:
 		>>> exp.set_subject(1)
 		>>> print 'Subject nr = %d' % exp.get('subject_nr')
@@ -154,23 +155,23 @@ class experiment(item.item):
 		</DOC>"""
 
 		# Set the subject nr and parity
-		self.set("subject_nr", nr)
+		self.set(u'subject_nr', nr)
 		if nr % 2 == 0:
-			self.set("subject_parity", "even")
+			self.set(u'subject_parity', u'even')
 		else:
-			self.set("subject_parity", "odd")
+			self.set(u'subject_parity', u'odd')
 
 	def read_definition(self, s):
 
 		"""
-		Extract a the definition of a single item from the string
+		Extracts a the definition of a single item from the string.
 
 		Arguments:
-		s -- the definition string
+		s	--	The definition string.
 
 		Returns:
 		A (str, str) tuple with the full string minus the definition string
-		and the definition string
+		and the definition string.
 		"""
 
 		# Read the string until the end of the definition
@@ -193,17 +194,16 @@ class experiment(item.item):
 	def parse_definition(self, item_type, item_name, string):
 
 		"""
-		Initialize a single definition, using the string, and
-		add it to the dictionary of items
+		Initializes a single definition, using the string, and
+		add it to the dictionary of items.
 
 		Arguments:
-		item_type -- the type of the item
-		item_name -- the name of the item
-		string -- the string containing the definition
+		item_type	--	The item's type.
+		item_name	--	The item's name.
+		string		--	The item's definition string.
 		"""
 
 		if plugins.is_plugin(item_type):
-
 			# Load a plug-in
 			if debug.enabled:
 				debug.msg(u"loading plugin '%s'" % item_type)
@@ -217,64 +217,37 @@ class experiment(item.item):
 					raise exceptions.script_error(u"Failed load plugin '%s'" % \
 						item_type)
 			self.items[item_name] = item
-
 		else:
-
-			# Load the module from the regular items
-			debug.msg(u"loading core plugin '%s'" % item_type)
-			if debug.enabled:
-				exec("from %s import %s" % (self.module_container(), item_type))
-			try:
-				if not self.debug:
-					exec("from %s import %s" % (self.module_container(), \
-						item_type))
-			except:
-				raise exceptions.script_error( \
-					u"Failed to import item '%s' as '%s'. " \
-					% (item_type, item_name)
-					+ "Perhaps the experiment requires a plug-in that is not available on your system.", \
-					full=False)
-
-			cmd = '%(item_type)s.%(item_type)s("%(item_name)s", self, u"""%(string)s""")' \
-				% {"item_type" : item_type, "item_name" : item_name, "string" \
-				: string.replace(u'"', u'\\"')}
-
-			if debug.enabled:
-				bytecode = compile(cmd, "<string>", "eval")
-				self.items[item_name] = eval(bytecode)
-			else:
-				try:
-					bytecode = compile(cmd, "<string>", "eval")
-					self.items[item_name] = eval(bytecode)
-				except Exception as e:
-					raise exceptions.script_error( \
-						u"Failed to instantiate module '%s' as '%s': %s" % \
-						(item_type, item_name, e))
+			# Load one of the core items
+			debug.msg(u"loading core item '%s' from '%s'" % (item_type, \
+				self.module_container()))
+			item_module = __import__(u'%s.%s' % (self.module_container(), \
+				item_type), fromlist=[u'dummy'])
+			item_class = getattr(item_module, item_type)
+			item = item_class(item_name, self, string)
+			self.items[item_name] = item
 
 	def from_string(self, string):
 
 		"""
-		Read the entire experiment from a string
+		Reads the entire experiment from a string.
 
 		Arguments:
-		string -- a definition string
+		string	--	The definition string.
 		"""
 
 		debug.msg(u"building experiment")
 		s = iter(string.split("\n"));
 		line = next(s, None)
 		while line != None:
-
 			get_next = True
 			try:
 				l = self.split(line)
-			except ValueError as e:									
+			except ValueError as e:
 				raise exceptions.script_error( \
 					u"Failed to parse script. Maybe it contains illegal characters or unclosed quotes?")
-
 			if len(l) > 0:
 				self.parse_variable(line)
-
 				# Parse definitions
 				if l[0] == u"define":
 					if len(l) != 3:
@@ -284,23 +257,24 @@ class experiment(item.item):
 					item_type = l[1]
 					item_name = self.sanitize(l[2])
 					line, def_str = self.read_definition(s)
-					get_next = False					
-					self.parse_definition(item_type, item_name, def_str)					
-
+					get_next = False
+					self.parse_definition(item_type, item_name, def_str)
+			# Advance to next line
 			if get_next:
-				line = next(s, None)
+				line = next(s, None)				
 
 	def run(self):
 
-		"""Run the experiment"""
+		"""Runs the experiment."""
 
-		self.running = True				
+		self.save_state()
+		self.running = True
 		self.init_display()
 		self.init_sound()
 		self.init_log()
 		self.reset_feedback()
 
-		print "experiment.run(): experiment started at %s" % time.ctime()
+		print u"experiment.run(): experiment started at %s" % time.ctime()
 
 		if self.start in self.items:
 			self.items[self.start].prepare()
@@ -310,42 +284,43 @@ class experiment(item.item):
 				"Could not find item '%s', which is the entry point of the experiment" \
 				% self.start)
 
-		print "experiment.run(): experiment finished at %s" % time.ctime()
+		print u"experiment.run(): experiment finished at %s" % time.ctime()
 
 		self.end()
 
 	def cleanup(self):
 
-		"""Call all the cleanup functions"""
+		"""Calls all the cleanup functions."""
 
 		while len(self.cleanup_functions) > 0:
 			func = self.cleanup_functions.pop()
-			debug.msg("calling cleanup function")
+			debug.msg(u"calling cleanup function")
 			func()
 
 	def end(self):
 
-		"""Nicely end the experiment"""
+		"""Nicely ends the experiment."""
 
 		from openexp import sampler, canvas
-		self.running = False			
+		self.running = False
 		try:
 			self._log.flush()
 			os.fsync(self._log)
 			self._log.close()
 		except:
-			pass									
+			pass
 		sampler.close_sound(self)
-		canvas.close_display(self)							
+		canvas.close_display(self)
 		self.cleanup()
+		self.restore_state()
 
 	def to_string(self):
 
 		"""
-		Encode the experiment into a string
+		Encodes the experiment into a string.
 
 		Returns:
-		A definition string for the experiment
+		A Unicode definition string for the experiment.
 		"""
 
 		s = u'# Generated by OpenSesame %s (%s)\n' % (misc.version, \
@@ -362,13 +337,13 @@ class experiment(item.item):
 	def resource(self, name):
 
 		"""
-		Retrieve a file from the resources folder
+		Retrieves a file from the resources folder.
 
 		Arguments:
-		name -- the file name
+		name	--	The file name.
 
 		Returns:
-		The full path to the file in the resources folder
+		The full path to the file in the resources folder.
 		"""
 
 		if self != None:
@@ -379,7 +354,7 @@ class experiment(item.item):
 		path = misc.resource(name)
 		if path == None:
 			raise Exception( \
-				"The resource '%s' could not be found in libopensesame.experiment.resource()" \
+				u"The resource '%s' could not be found in libopensesame.experiment.resource()" \
 				% name)
 		return path
 
@@ -391,21 +366,26 @@ class experiment(item.item):
 		simply returns the path.
 
 		Arguments:
-		path -- The filename.
+		path	--	The filename.
 
 		Returns:
 		The full path to the file.
-		
-		Example:		
+
+		Example:
 		>>> image_path = exp.get_file('my_image.png')
 		>>> my_canvas = exp.offline_canvas()
 		>>> my_canvas.image(image_path)
 		</DOC>"""
 
-		if type(path) not in(unicode, str):
+		if not isinstance(path, basestring):
 			raise exceptions.runtime_error( \
-				"A string should be passed to experiment.get_file(), not '%s'" \
+				u"A string should be passed to experiment.get_file(), not '%s'" \
 				% path)
+		if path.strip() == u'':
+			raise exceptions.runtime_error( \
+				u"An empty string was passed to experiment.get_file(). Please specify a valid filename.")				
+		if isinstance(path, unicode):
+			path = path.encode(misc.filesystem_encoding())
 		if os.path.exists(os.path.join(self.pool_folder, path)):
 			return os.path.join(self.pool_folder, path)
 		elif self.experiment_path != None and os.path.exists(os.path.join( \
@@ -421,14 +401,14 @@ class experiment(item.item):
 
 		Returns:
 		A Boolean indicating if the file is in the pool.
-		
-		Example:		
+
+		Example:
 		>>> if not exp.file_in_pool('my_image.png'):
 		>>> 	print 'my_image.png could not be found!'
 		>>> else:
 		>>> 	image_path = exp.get_file('my_image.png')
 		>>> 	my_canvas = exp.offline_canvas()
-		>>> 	my_canvas.image(image_path)		
+		>>> 	my_canvas.image(image_path)
 		</DOC>"""
 
 		return os.path.exists(self.get_file(path))
@@ -436,60 +416,60 @@ class experiment(item.item):
 	def save(self, path, overwrite=False):
 
 		"""
-		Save the experiment to file. If no extension is provided,
+		Saves the experiment to file. If no extension is provided,
 		.opensesame.tar.gz is chosen by default.
 
 		Arguments:
-		path -- the target file to save to
+		path		--	The target file to save to.
 
 		Keyword arguments:
-		overwrite -- a boolean indicating if existing files should be
-					 overwritten (default=False)
+		overwrite	--	A boolean indicating if existing files should be
+						overwritten. (default=False)
 
 		Returns:
-		The path on successfull saving or False otherwise
+		The path on successfull saving or False otherwise.
 		"""
 
-		debug.msg("asked to save '%s'" % path)
+		debug.msg(u"asked to save '%s'" % path)
 
 		# Determine the extension
 		ext = os.path.splitext(path)[1].lower()
 
 		# If the extension is .opensesame, save the script as plain text
-		if ext == ".opensesame":
+		if ext == u".opensesame":
 			if os.path.exists(path) and not overwrite:
 				return False
-			debug.msg("saving as .opensesame file")
-			f = open(path, "w")
+			debug.msg(u"saving as .opensesame file")
+			f = open(path, u"w")
 			f.write(self.usanitize(self.to_string()))
 			f.close()
 			self.experiment_path = os.path.dirname(path)
 			return path
 
 		# Use the .opensesame.tar.gz extension by default
-		if path[-len(".opensesame.tar.gz"):] != ".opensesame.tar.gz":
-			path += ".opensesame.tar.gz"
+		if path[-len(u".opensesame.tar.gz"):] != u".opensesame.tar.gz":
+			path += u".opensesame.tar.gz"
 
 		if os.path.exists(path) and not overwrite:
 			return False
 
-		debug.msg("saving as .opensesame.tar.gz file")
+		debug.msg(u"saving as .opensesame.tar.gz file")
 
 		# Write the script to a text file
 		script = self.to_string()
-		script_path = os.path.join(self.pool_folder, "script.opensesame")
-		f = open(script_path, "w")
+		script_path = os.path.join(self.pool_folder, u"script.opensesame")
+		f = open(script_path, u"w")
 		f.write(self.usanitize(script))
 		f.close()
 
 		# Create the archive in a a temporary folder and move it
 		# afterwards. This hack is needed, because tarfile fails
 		# on a Unicode path.
-		tmp_path = tempfile.mktemp(suffix = ".opensesame.tar.gz")
-		tar = tarfile.open(tmp_path, "w:gz")
-		tar.add(script_path, "script.opensesame")
+		tmp_path = tempfile.mktemp(suffix = u".opensesame.tar.gz")
+		tar = tarfile.open(tmp_path, u"w:gz")
+		tar.add(script_path, u"script.opensesame")
 		os.remove(script_path)
-		tar.add(self.pool_folder, "pool", True)
+		tar.add(self.pool_folder, u"pool", True)
 		tar.close()
 
 		# Move the file to the intended location
@@ -503,73 +483,77 @@ class experiment(item.item):
 		"""
 		If the path exists, open the file, extract the pool and return the
 		contents of the script.opensesame. Otherwise just return the input
-		string, because it probably was a definition to begin with
+		string, because it probably was a definition to begin with.
 
 		Arguments:
-		path -- the file to be opened
+		path	--	The file to be opened, or a definition string.
 
 		Returns:
-		A unicode defition string
+		A unicode defition string.
 		"""
+		
+		# Convert to string using the filesystem encoding 
+		if isinstance(path, unicode):
+			path = path.encode(misc.filesystem_encoding())		
 
 		# If the path is not a path at all, but a string containing
-		# the script, return it
-		
+		# the script, return it. Also, convert the path back to Unicode before
+		# returning.
 		if not os.path.exists(path):
-			debug.msg("opening from unicode string")
+			debug.msg(u"opening from unicode string")
 			self.experiment_path = None
-			return path
+			return path.decode(misc.filesystem_encoding())
 
 		# If the file is a regular text script,
 		# read it and return it
-		ext = ".opensesame.tar.gz"
+		ext = u".opensesame.tar.gz"
 		if path[-len(ext):] != ext:
-			debug.msg("opening .opensesame file")
+			debug.msg(u"opening .opensesame file")
 			self.experiment_path = os.path.dirname(path)
-			return self.unsanitize(open(path, "rU").read())
+			return self.unsanitize(open(path, u"rU").read())
 
-		debug.msg("opening .opensesame.tar.gz file")
+		debug.msg(u"opening .opensesame.tar.gz file")
 
 		# If the file is a .tar.gz archive, extract
 		# the pool to the pool folder and return the
 		# contents of opensesame.script
-		tar = tarfile.open(path, "r:gz")
+		tar = tarfile.open(path, u"r:gz")
 		for name in tar.getnames():
 			folder, fname = os.path.split(name)
-			if folder == "pool":
-				debug.msg("extracting '%s'" % name)
+			if folder == u"pool":
+				debug.msg(u"extracting '%s'" % name)
 				tar.extract(name, self.pool_folder)
 				os.rename(os.path.join(self.pool_folder, name), os.path.join( \
 					self.pool_folder, fname))
 				os.rmdir(os.path.join(self.pool_folder, folder))
 
-		script_path = os.path.join(self.pool_folder, "script.opensesame")
-		tar.extract("script.opensesame", self.pool_folder)
-		script = self.unsanitize(open(script_path, "rU").read())
+		script_path = os.path.join(self.pool_folder, u"script.opensesame")
+		tar.extract(u"script.opensesame", self.pool_folder)
+		script = self.unsanitize(open(script_path, u"rU").read())
 		os.remove(script_path)
 		self.experiment_path = os.path.dirname(path)
 		return script
 
 	def reset_feedback(self):
 
-		"""Reset the feedback variables (acc, avg_rt, etc.)"""
+		"""Resets the feedback variables (acc, avg_rt, etc.)."""
 
 		self.total_responses = 0
 		self.total_correct = 0
 		self.total_response_time = 0
-		self.avg_rt = "undefined"
-		self.average_response_time = "undefined"
-		self.accuracy = "undefined"
-		self.acc = "undefined"
-		
+		self.avg_rt = u"undefined"
+		self.average_response_time = u"undefined"
+		self.accuracy = u"undefined"
+		self.acc = u"undefined"
+
 	def var_info(self):
 
 		"""
-		Return a list of (name, value) tuples with variable descriptions
-		for the main experiment
+		Returns a list of (name, value) tuples with variable descriptions
+		for the main experiment.
 
 		Returns:
-		A list of tuples
+		A list of tuples.
 		"""
 
 		l = []
@@ -577,26 +561,26 @@ class experiment(item.item):
 			l.append( (var, self.variables[var]) )
 		return l
 
-	def var_list(self, filt=''):
+	def var_list(self, filt=u''):
 
 		"""
-		Return a list of (name, value, description) tuples with variable
+		Returns a list of (name, value, description) tuples with variable
 		descriptions for all items
 
 		Keyword arguments:
-		filt -- a search string to filter by
+		filt	--	A search string to filter by. (default=u'')
 
 		Returns:
-		A list of tuples
+		A list of tupless
 		"""
 
-		l = []				
+		l = []
 		# Create a dictionary of items that also includes the experiment
-		item_dict = dict(self.items.items() + [('global', self)]).items()
+		item_dict = dict(self.items.items() + [(u'global', self)]).items()
 		seen = []
 		for item_name, item in item_dict:
-			# Create a dictionary of variables that includes the broadcasted ones
-			# as wel as the indirectly registered ones (using item.set())
+			# Create a dictionary of variables that includes the broadcasted
+			# ones as wel as the indirectly registered ones (using item.set())
 			var_dict = item.var_info() + item.variables.items()
 			for var, val in var_dict:
 				if var not in seen and (filt in var.lower() or filt in \
@@ -604,91 +588,108 @@ class experiment(item.item):
 					l.append( (var, val, item_name) )
 					seen.append(var)
 		return l
-				
+
 	def init_sound(self):
 
-		"""Intialize the sound backend"""
+		"""Intializes the sound backend."""
 
 		from openexp import sampler
 		sampler.init_sound(self)
 
 	def init_display(self):
 
-		"""Initialize the canvas backend"""
+		"""Initializes the canvas backend."""
 
 		from openexp import canvas
 		canvas.init_display(self)
 
 	def init_log(self):
 
-		"""Open the logile"""
-		
+		"""Opens the logile."""
+
 		# Do not open the logfile if it's already open
 		if self._log != None:
 			return
 		# Open the logfile
 		if self.logfile == None:
 			self.logfile = u'defaultlog.txt'
-		self._log = codecs.open(self.logfile, 'w', encoding=self.encoding)
-		print "experiment.init_log(): using '%s' as logfile (%s)" % \
+		self._log = codecs.open(self.logfile, u'w', encoding=self.encoding)
+		print u"experiment.init_log(): using '%s' as logfile (%s)" % \
 			(self.logfile, self.logfile_codec)
-						
+
+	def save_state(self):
+
+		"""
+		Saves the system state so that it can be restored after the experiment.
+		"""
+		
+		from libopensesame import inline_script
+		inline_script.save_state()
+	
+	def restore_state(self):
+
+		"""Restores the system to the state as saved by save_state()."""
+
+		from libopensesame import inline_script
+		inline_script.restore_state()
+
 	def _sleep_func(self, ms):
 
 		"""
-		Sleeps for a specific time. 
-		
+		Sleeps for a specific time.
+
 		* This is a stub that should be replaced by a proper function by the
 		  canvas backend. See openexp._canvas.legacy.init_display()
-		
+
 		Arguments:
-		ms -- the sleep period
+		ms	--	The sleep duration.
 		"""
-		
+
 		raise exceptions.runtime_error( \
-			"experiment._sleep_func(): This function should be set by the canvas backend." \
-			)			
+			u"experiment._sleep_func(): This function should be set by the canvas backend." \
+			)
 
 	def _time_func(self):
 
 		"""
-		Get the time
-		
+		Gets the time.
+
 		* This is a stub that should be replaced by a proper function by the
 		  canvas backend. See openexp._canvas.legacy.init_display()
-		  
+
 		Returns:
 		A timestamp in milliseconds. Depending on the backend, this may be an
-		int or a float
+		int or a float.
 		"""
 
 		raise exceptions.runtime_error( \
-			"experiment._time_func(): This function should be set by the canvas backend." \
+			u"experiment._time_func(): This function should be set by the canvas backend." \
 			)
 
+
 def clean_up(verbose=False):
 
 	"""
-	Clean up the temporary pool folders
+	Cleans up the temporary pool folders.
 
 	Keyword arguments:
-	verbose -- a boolean indicating if debugging output should be given
-			   (default=False)
+	verbose		--	A boolean indicating if debugging output should be given.
+					(default=False)
 	"""
 
 	from openexp import canvas
 	global pool_folders
 	if verbose:
-		print "experiment.clean_up()"
+		print u"experiment.clean_up()"
 
 	for path in pool_folders:
 		if verbose:
-			print "experiment.clean_up(): removing '%s'" % path
+			print u"experiment.clean_up(): removing '%s'" % path
 		try:
 			shutil.rmtree(path)
 		except:
 			if verbose:
-				print "experiment.clean_up(): failed to remove '%s'" % path
+				print u"experiment.clean_up(): failed to remove '%s'" % path
 	canvas.clean_up(verbose)
 
 
