@@ -37,14 +37,14 @@ class item(object):
 	def __init__(self, name, experiment, string=None):
 
 		"""
-		Constructor
+		Constructor.
 
 		Arguments:
-		name -- The name of the item.
-		experiment -- The experiment.
+		name 		--	The name of the item.
+		experiment 	--	The experiment object.
 
 		Keyword arguments:
-		string -- An item definition string (default = None).
+		string		--	An definition string. (default=None).
 		"""
 
 		self.name = name
@@ -52,20 +52,24 @@ class item(object):
 		self.debug = debug.enabled
 		self.count = 0
 
-		# A number of keywords are reserved, which means that they cannot be used
-		# as variable names
-		self.reserved_words = ['experiment', 'variables', 'comments', 'item_type']
+		# A number of keywords are reserved, which means that they cannot be
+		# used as variable names
+		self.reserved_words = [u'experiment', u'variables', u'comments', \
+			u'item_type']
 		for attr in dir(item):
 			if hasattr(getattr(item, attr), '__call__'):
 				self.reserved_words.append(attr)
 
 		self._get_lock = None
 
-		if not hasattr(self, "item_type"):
-			self.item_type = "item"
-		if not hasattr(self, "description"):
-			self.description = "Default description"
-		if not hasattr(self, "round_decimals"):
+		if not hasattr(self, u'item_type'):
+			prefix = self.experiment.item_prefix()
+			self.item_type = self.__class__.__name__
+			if self.item_type.startswith(prefix):
+				self.item_type = self.item_type[len(prefix):]
+		if not hasattr(self, u'description'):
+			self.description = u'Default description'
+		if not hasattr(self, u'round_decimals'):
 			self.round_decimals = 2
 		self.variables = {}
 		self.comments = []
@@ -111,15 +115,7 @@ class item(object):
 		# all from_string() derivatives need to be modified
 		if self.parse_comment(line):
 			return True
-
-
 		l = self.split(line.strip())
-		try:
-			l = self.split(line.strip())
-		except Exception as e:
-			raise exceptions.script_error( \
-				u"Error parsing '%s' in item '%s': %s" % (line, self.name, e))
-
 		if len(l) > 0 and l[0] == u'set':
 			if len(l) != 3:
 				raise exceptions.script_error( \
@@ -254,10 +250,10 @@ class item(object):
 					self.set(textblock_var, textblock_val)
 					textblock_var = None
 			# The beginning of a textblock. A new textblock is only started when
-			# a textblock is not already ongoing, and only if the textblock start
-			# is of the format __VARNAME__
-			elif line_stripped[:2] == u'__' and line_stripped[-2:] == u'__' and \
-				textblock_var == None:
+			# a textblock is not already ongoing, and only if the textblock
+			# start is of the format __VARNAME__
+			elif line_stripped[:2] == u'__' and line_stripped[-2:] == u'__' \
+				and textblock_var == None:
 				textblock_var = line_stripped[2:-2]
 				if textblock_var in self.reserved_words:
 					textblock_var = u'_' + textblock_var
@@ -274,7 +270,7 @@ class item(object):
 				if strip_tab:
 					textblock_val += line[1:] + u'\n'
 				else:
-					textblock_val += line + '\n'
+					textblock_val += line + u'\n'
 			# Parse regular variables
 			elif not self.parse_variable(line):
 				self.parse_line(line)
@@ -419,7 +415,7 @@ class item(object):
 		Example:
 		>>> if self.get('cue') == 'valid':
 		>>>		print 'This is a validly cued trial'
-		
+
 		Example 2:
 		>>> exp.set('var1', 'I like [var2]')
 		>>> exp.set('var2', 'OpenSesame')
@@ -913,8 +909,13 @@ class item(object):
 		"""
 
 		import shlex
-		return [chunk.decode(self.encoding) for chunk in shlex.split(u.encode( \
-			self.encoding))]
+		try:
+			return [chunk.decode(self.encoding) for chunk in shlex.split( \
+				u.encode(self.encoding))]
+		except:
+			raise exceptions.script_error( \
+				u'Failed to parse line "%s". Is there a closing quotation missing?' \
+				% u)
 
 	def color_check(self, col):
 
@@ -958,7 +959,7 @@ class item(object):
 		</DOC>"""
 
 		# This function is set by item.prepare()
-		raise exceptions.openexp_error( \
+		raise exceptions.runtime_error( \
 			u'item.sleep(): This function should be set by the canvas backend.')
 
 	def time(self):
@@ -974,7 +975,7 @@ class item(object):
 		</DOC>"""
 
 		# This function is set by item.prepare()
-		raise exceptions.openexp_error( \
+		raise exceptions.runtime_error( \
 			u"item.time(): This function should be set by the canvas backend.")
 
 	def log(self, msg):
@@ -1004,3 +1005,4 @@ class item(object):
 
 		self.experiment._log.flush()
 		os.fsync(self.experiment._log)
+
