@@ -20,7 +20,11 @@ along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 __author__ = "Sebastiaan Mathot"
 __license__ = "GPLv3"
 
-# Redirect certain things so that the old way of from libqtopensesame import
-# qtplugin still works.
-from libqtopensesame.items import qtplugin
-from libqtopensesame.widgets import inline_editor, pool_widget
+from PyQt4 import QtCore
+if QtCore.QCoreApplication != None:	
+	# Redirect certain things so that the old way of from libqtopensesame import
+	# qtplugin still works.
+	from libqtopensesame.items import qtplugin
+	from libqtopensesame.widgets import inline_editor, pool_widget
+else:
+	from libqtopensesame.misc import dummy as qtplugin
