@@ -24,7 +24,8 @@ from PyQt4 import QtCore, QtGui
 import os.path
 import sip
 from libopensesame import debug, exceptions, item
-from libqtopensesame.widgets import inline_editor, header_widget
+from libqtopensesame.widgets import inline_editor, header_widget, \
+	user_hint_widget
 from libqtopensesame.misc import _
 
 class qtitem(QtCore.QObject):
@@ -58,9 +59,14 @@ class qtitem(QtCore.QObject):
 
 		"""Open the help tab"""
 
-		path = self.experiment.help(self.item_type + ".html")
-		if not os.path.exists(path):
-			path = self.experiment.help("missing.html")
+		md_path = self.experiment.help(self.item_type + '.md')
+		html_path = self.experiment.help(self.item_type + '.html')
+		if os.path.exists(md_path):
+			path = md_path
+		elif os.path.exists(html_path):
+			path = html_path
+		else:
+			path = self.experiment.help('missing.html')
 		self.experiment.main_window.ui.tabwidget.open_browser(path)
 
 	def open_tab(self):
@@ -77,6 +83,8 @@ class qtitem(QtCore.QObject):
 		"""Build the GUI controls"""
 
 		self.header = header_widget.header_widget(self)
+		self.user_hint_widget = user_hint_widget.user_hint_widget( \
+			self.experiment.main_window, self)
 
 		self.header_hbox = QtGui.QHBoxLayout()
 		self.header_hbox.addWidget(self.experiment.label_image(self.item_type))
@@ -110,7 +118,8 @@ class qtitem(QtCore.QObject):
 		self.edit_vbox = QtGui.QVBoxLayout()
 		self.edit_vbox.setMargin(16)
 		self.edit_vbox.addWidget(self.header_widget)
-		self.edit_vbox.addWidget(self.edit_grid_widget)
+		self.edit_vbox.addWidget(self.user_hint_widget)
+		self.edit_vbox.addWidget(self.edit_grid_widget)		
 		if stretch:
 			self.edit_vbox.addStretch()
 		self._edit_widget = QtGui.QWidget()
@@ -131,6 +140,7 @@ class qtitem(QtCore.QObject):
 		if not stretch:
 			debug.msg("passing the stretch argument is deprecated", \
 				reason="deprecation")
+		self.user_hint_widget.clear()
 		self.header.restore_name(False)
 		self.header.refresh()
 		self._edit_widget.__edit_item__ = self.name
@@ -138,6 +148,7 @@ class qtitem(QtCore.QObject):
 			self.open_script_tab()
 			return
 		self.auto_edit_widget()
+		self.user_hint_widget.refresh()
 		return self._edit_widget
 
 	def apply_name_change(self, rebuild=True):
@@ -154,14 +165,12 @@ class qtitem(QtCore.QObject):
 		# Sanitize the name, check if it is new and valid, and if so, rename
 		new_name = self.experiment.sanitize(self.header.edit_name.text(), \
 			strict=True, allow_vars=False)
-		if new_name.lower() == self.name.lower():
-			self.header.edit_name.setText(self.name)
-			return
-		valid = self.experiment.check_name(new_name)
-		if valid != True:
-			self.experiment.notify(valid)
-			self.header.edit_name.setText(self.name)
-			return
+		if new_name.lower() != self.name.lower():
+			valid = self.experiment.check_name(new_name)
+			if valid != True:
+				self.experiment.notify(valid)
+				self.header.edit_name.setText(self.name)
+				return
 		old_name = self.name
 		self.name = new_name
 		self._edit_widget.__edit_item__	= new_name
@@ -355,8 +364,8 @@ class qtitem(QtCore.QObject):
 
 		hbox = QtGui.QHBoxLayout()
 		hbox.addWidget(self.experiment.label_image("%s" % self.item_type))
-		hbox.addWidget(QtGui.QLabel(_("Editing script for <b>%s</b> - %s") % \
-			(self.name, self.item_type)))
+		self.script_header = QtGui.QLabel()			
+		hbox.addWidget(self.script_header)
 		hbox.addStretch()
 		hbox.setContentsMargins(0,0,0,0)
 		hwidget = QtGui.QWidget()
@@ -378,6 +387,9 @@ class qtitem(QtCore.QObject):
 		The QWidget containing the script tab
 		"""
 
+		self.script_header.setText( \
+			_("Editing script for <b>%s</b> - %s") % (self.name, \
+			self.item_type))
 		script = ""
 		for s in self.to_string().split("\n")[1:]:
 			script += self.strip_script_line(s)
@@ -588,8 +600,8 @@ class qtitem(QtCore.QObject):
 			debug.msg("applying pending script changes")
 			self.apply_script_changes(catch=False)
 			return True
-		return False
-
+		return False		
+		
 	def auto_edit_widget(self):
 
 		"""Update the GUI controls based on the auto-widgets"""
@@ -621,21 +633,35 @@ class qtitem(QtCore.QObject):
 		for var, spinbox in self.auto_spinbox.iteritems():
 			spinbox.editingFinished.disconnect()
 			if self.has(var):
-				try:
-					spinbox.setValue(self.get(var, _eval=False))
-				except Exception as e:
-					self.experiment.notify(_("Failed to set control '%s': %s") \
-						% (var, e))
-			spinbox.editingFinished.connect(self.apply_edit_changes)
+				val = self.get(var, _eval=False)
+				if type(val) in (float, int):						
+					try:
+						spinbox.setValue(val)
+					except Exception as e:
+						self.experiment.notify(_( \
+							"Failed to set control '%s': %s") % (var, e))
+				else:
+					spinbox.setDisabled(True)
+					self.user_hint_widget.add_user_hint(_( \
+						'"%s" is defined using variables and can only be edited through the script.' \
+						% var))
+			spinbox.editingFinished.connect(self.apply_edit_changes)			
 
 		for var, slider in self.auto_slider.iteritems():
 			slider.valueChanged.disconnect()
 			if self.has(var):
-				try:
-					slider.setValue(self.get(var, _eval=False))
-				except Exception as e:
-					self.experiment.notify(_("Failed to set control '%s': %s") \
-						% (var, e))
+				val = self.get(var, _eval=False)
+				if type(val) in (float, int):	
+					try:
+						slider.setValue(val)
+					except Exception as e:
+						self.experiment.notify(_( \
+							"Failed to set control '%s': %s") % (var, e))						
+				else:
+					slider.setDisabled(True)
+					self.user_hint_widget.add_user_hint(_( \
+						'"%s" is defined using variables and can only be edited through the script.' \
+						% var))
 			slider.valueChanged.connect(self.apply_edit_changes)
 
 		for var, checkbox in self.auto_checkbox.iteritems():
@@ -731,7 +757,7 @@ class qtitem(QtCore.QObject):
 
 		debug.msg()
 		for var, edit in self.auto_line_edit.iteritems():
-			if type(var) == str:
+			if edit.isEnabled() and isinstance(var, basestring):
 				val = unicode(edit.text()).strip()
 				if val != "":
 					self.set(var, val)
@@ -744,19 +770,19 @@ class qtitem(QtCore.QObject):
 					self.unset(var)
 
 		for var, combobox in self.auto_combobox.iteritems():
-			if type(var) == str:
+			if combobox.isEnabled() and isinstance(var, basestring):
 				self.set(var, unicode(combobox.currentText()))
 
 		for var, spinbox in self.auto_spinbox.iteritems():
-			if type(var) == str:
+			if spinbox.isEnabled() and isinstance(var, basestring):
 				self.set(var, spinbox.value())
 
 		for var, slider in self.auto_slider.iteritems():
-			if type(var) == str:
+			if slider.isEnabled() and isinstance(var, basestring):
 				self.set(var, slider.value())
 
 		for var, checkbox in self.auto_checkbox.iteritems():
-			if type(var) == str:
+			if checkbox.isEnabled() and isinstance(var, basestring):
 				if checkbox.isChecked():
 					val = "yes"
 				else:
@@ -764,7 +790,7 @@ class qtitem(QtCore.QObject):
 				self.set(var, val)
 
 		for var, editor in self.auto_editor.iteritems():
-			if type(var) == str:
+			if isinstance(var, basestring):
 				self.set(var, editor.edit.toPlainText())
 				editor.setModified(False)
 
