@@ -21,7 +21,7 @@ from PyQt4 import QtCore, QtGui
 from libqtopensesame.misc import includes, config, _
 from libqtopensesame.misc.config import cfg
 from libqtopensesame.items import experiment
-from libopensesame import debug, exceptions
+from libopensesame import debug, exceptions, misc
 import libopensesame.exceptions
 import libopensesame.experiment
 import libopensesame.plugins
@@ -36,7 +36,7 @@ import subprocess
 class qtopensesame(QtGui.QMainWindow):
 
 	"""The main class of the OpenSesame GUI"""
-	
+
 	# Set to False for release!
 	devmode = False
 
@@ -46,7 +46,7 @@ class qtopensesame(QtGui.QMainWindow):
 		Constructor. This does very little, except prepare the app to be shown
 		as rapidly as possible. The actual GUI initialization is handled by
 		resume_init().
-		
+
 		Arguments:
 		app -- the QApplication
 
@@ -54,9 +54,16 @@ class qtopensesame(QtGui.QMainWindow):
 		parent -- a link to the parent window
 		"""
 
-		QtGui.QMainWindow.__init__(self, parent)
+		if sys.platform == 'darwin':
+			# Workaround for Qt issue on OS X that causes QMainWindow to
+			# hide when adding QToolBar, see
+			# https://bugreports.qt-project.org/browse/QTBUG-4300
+			QtGui.QMainWindow.__init__(self, parent, \
+				QtCore.Qt.MacWindowToolBarButtonHint)
+		else:
+			QtGui.QMainWindow.__init__(self, parent)
 		self.app = app
-		self.first_show = True		
+		self.first_show = True
 
 	def resume_init(self):
 
@@ -68,22 +75,22 @@ class qtopensesame(QtGui.QMainWindow):
 		from libqtopensesame.misc import theme, dispatch
 		import platform
 		import random
-		
+
 		# Initialize random number generator
 		random.seed()
 
 		# Check the filesystem encoding for debugging purposes
-		debug.msg('filesystem encoding: %s' % sys.getfilesystemencoding())
-		
+		debug.msg('filesystem encoding: %s' % misc.filesystem_encoding())
+
 		# Restore the configuration
 		self.restore_config()
-		
+
 		# Setup dispatch
 		self.dispatch = dispatch.dispatch(self)
-				
+
 		# Setup the UI
 		self.ui = opensesame_ui.Ui_opensesame_mainwindow()
-		self.ui.setupUi(self)	
+		self.ui.setupUi(self)
 		self.ui.toolbar_items.main_window = self
 		self.ui.itemtree.main_window = self
 		self.ui.table_variables.main_window = self
@@ -95,12 +102,12 @@ class qtopensesame(QtGui.QMainWindow):
 		self.codename = misc.codename
 		self.lock_refresh = False
 		self.unsaved_changes = False
-		
+
 		# Parse the command line
 		self.parse_command_line()
-		
+
 		# Load a theme
-		self.theme = theme.theme(self, self.options._theme)		
+		self.theme = theme.theme(self, self.options._theme)
 
 		# Determine the home folder
 		self.home_folder = libopensesame.misc.home_folder()
@@ -120,13 +127,13 @@ class qtopensesame(QtGui.QMainWindow):
 
 		# Set the window message
 		self.window_message(_("Welcome to OpenSesame %s") % self.version)
-		
+
 		# Set the window icon
 		self.setWindowIcon(self.theme.qicon("opensesame"))
 
 		# Make the connections
 		self.ui.itemtree.itemClicked.connect(self.open_item)
-		self.ui.action_quit.triggered.connect(self.close)
+		self.ui.action_quit.triggered.connect(self.closeEvent)
 		self.ui.action_new.triggered.connect(self.new_file)
 		self.ui.action_open.triggered.connect(self.open_file)
 		self.ui.action_save.triggered.connect(self.save_file)
@@ -152,7 +159,7 @@ class qtopensesame(QtGui.QMainWindow):
 			self.ui.tabwidget.open_general_help)
 		self.ui.action_about.triggered.connect(self.ui.tabwidget.open_about)
 		self.ui.action_online_documentation.triggered.connect( \
-			self.ui.tabwidget.open_osdoc)		
+			self.ui.tabwidget.open_osdoc)
 		self.ui.action_check_for_update.triggered.connect(self.check_update)
 		self.ui.action_open_autosave_folder.triggered.connect( \
 			self.open_autosave_folder)
@@ -213,10 +220,6 @@ class qtopensesame(QtGui.QMainWindow):
 			QtGui.QKeySequence(), self, \
 			self.ui.pool_widget.ui.edit_pool_filter.setFocus)
 
-		# On Mac OS (darwin) hide, the run in Window functionality
-		if sys.platform == "darwin":
-			self.ui.action_run_in_window.setDisabled(True)				
-
 		# Create the initial experiment
 
 		self.experiment = experiment.experiment(self, "New experiment", \
@@ -224,14 +227,14 @@ class qtopensesame(QtGui.QMainWindow):
 				"default.opensesame")), "r").read())
 
 		# Build the items toolbar
-		self.set_status(_("Welcome to OpenSesame %s") % self.version)		
+		self.set_status(_("Welcome to OpenSesame %s") % self.version)
 		self.restore_state()
 		self.refresh_plugins()
 		self.start_autosave_timer()
 		self.update_recent_files()
-		self.clean_autosave()		
+		self.clean_autosave()
 		self.set_unsaved(False)
-		
+
 	def parse_command_line(self):
 
 		"""Parse command line options"""
@@ -254,7 +257,7 @@ class qtopensesame(QtGui.QMainWindow):
 		group.add_option("-c", "--config", action="store", dest="_config", \
 			help="Set a configuration option, e.g, '--config auto_update_check=False;scintilla_font_size=10'. For a complete list of configuration options, please refer to the source of config.py.")
 		group.add_option("-t", "--theme", action="store", dest="_theme", \
-			help="Specify a GUI theme")							
+			help="Specify a GUI theme")
 		group.add_option("-d", "--debug", action="store_true", dest="debug", \
 			help="Print lots of debugging messages to the standard output")
 		group.add_option("-s", "--stack", action="store_true", dest="_stack", \
@@ -266,25 +269,25 @@ class qtopensesame(QtGui.QMainWindow):
 		group.add_option("--ipython", action="store_true", dest="ipython", \
 			help="Enable the IPython interpreter")
 		group.add_option("--locale", action="store_true", dest="locale", \
-			help="Specify localization")			
+			help="Specify localization")
 		group.add_option("--catch-translatables", action="store_true", \
-			dest="catch_translatables", help="Log all translatable text")						
+			dest="catch_translatables", help="Log all translatable text")
 		group.add_option("--no-global-resources", action="store_true", dest="no_global_resources", \
 			help="Do not use global resources on *nix")
 		parser.add_option_group(group)
-		self.options, args = parser.parse_args(sys.argv)	
+		self.options, args = parser.parse_args(sys.argv)
 		if self.options.run and self.options.run_in_window:
-			parser.error("Options -r / --run and -w / --run-in-window are mutually exclusive.")			
-			
+			parser.error("Options -r / --run and -w / --run-in-window are mutually exclusive.")
+
 	def restore_config(self):
-	
+
 		"""Restores the configuration settings, but doesn't apply anything"""
-	
+
 		debug.msg()
 		settings = QtCore.QSettings("cogscinl", "opensesame")
 		settings.beginGroup("MainWindow")
 		config.restore_config(settings)
-		settings.endGroup()			
+		settings.endGroup()
 
 	def restore_state(self):
 
@@ -298,7 +301,7 @@ class qtopensesame(QtGui.QMainWindow):
 		self.resize(cfg.size)
 		self.move(cfg.pos)
 		self.experiment.auto_response = cfg.auto_response
-		
+
 		# Set the keyboard shortcuts
 		self.ui.shortcut_itemtree.setKey(QtGui.QKeySequence( \
 			cfg.shortcut_itemtree))
@@ -311,13 +314,13 @@ class qtopensesame(QtGui.QMainWindow):
 
 		# Unpack the string with recent files and only remember those that exist
 		self.recent_files = []
-		for path in cfg.recent_files.split(";;"):		
+		for path in cfg.recent_files.split(";;"):
 			if os.path.exists(path):
 				debug.msg("adding recent file '%s'" % path)
 				self.recent_files.append(path)
 			else:
 				debug.msg("missing recent file '%s'" % path)
-				
+
 		self.ui.action_enable_auto_response.setChecked( \
 			self.experiment.auto_response)
 		self.ui.action_onetabmode.setChecked(cfg.onetabmode)
@@ -333,7 +336,7 @@ class qtopensesame(QtGui.QMainWindow):
 				QtCore.Qt.ToolButtonIconOnly)
 		self.set_style()
 		self.theme.set_toolbar_size(cfg.toolbar_size)
-		
+
 	def restore_window_state(self):
 
 		"""
@@ -341,8 +344,8 @@ class qtopensesame(QtGui.QMainWindow):
 		don't wait until the end, the window gets distorted again.
 		"""
 
-		self.restoreState(config.get_config('_initial_window_state'))		
-		self.restoreGeometry(config.get_config('_initial_window_geometry'))		
+		self.restoreState(config.get_config('_initial_window_state'))
+		self.restoreGeometry(config.get_config('_initial_window_geometry'))
 
 	def save_state(self):
 
@@ -359,7 +362,7 @@ class qtopensesame(QtGui.QMainWindow):
 		settings.setValue("auto_response", self.experiment.auto_response)
 		settings.setValue("toolbar_text", \
 			self.ui.toolbar_main.toolButtonStyle() == \
-			QtCore.Qt.ToolButtonTextUnderIcon)		
+			QtCore.Qt.ToolButtonTextUnderIcon)
 		settings.setValue("recent_files", ";;".join(self.recent_files))
 		settings.endGroup()
 
@@ -428,22 +431,25 @@ class qtopensesame(QtGui.QMainWindow):
 		"""Autosave the experiment if there are unsaved changes"""
 
 		if not self.unsaved_changes:
-			self.set_status("No unsaved changes, skipping backup")
-			autosave_path = ""
+			self.set_status(u'No unsaved changes, skipping backup')
+			autosave_path = u''
 		else:
 			_current_path = self.current_path
+			_experiment_path = self.experiment.experiment_path
 			_unsaved_changes = self.unsaved_changes
 			_window_msg = self.window_msg
 			self.current_path = os.path.join(self.autosave_folder, \
-				"%s.opensesame.tar.gz" % unicode(time.ctime()).replace(":", "_"))
+				u'%s.opensesame.tar.gz'% unicode(time.ctime()).replace(':', \
+				'_'))
 			debug.msg("saving backup as %s" % self.current_path)
 			try:
 				self.save_file(False, remember=False, catch=False)
-				self.set_status(_("Backup saved as %s") % self.current_path)
+				self.set_status(_('Backup saved as %s') % self.current_path)
 			except:
-				self.set_status(_("Failed to save backup ..."))
+				self.set_status(_('Failed to save backup ...'))
 			autosave_path = self.current_path
 			self.current_path = _current_path
+			self.experiment.experiment_path = _experiment_path
 			self.set_unsaved(_unsaved_changes)
 			self.window_message(_window_msg)
 		self.start_autosave_timer()
@@ -451,7 +457,6 @@ class qtopensesame(QtGui.QMainWindow):
 
 	def clean_autosave(self):
 
-
 		"""Remove old files from the back-up folder"""
 
 		for path in os.listdir(self.autosave_folder):
@@ -591,19 +596,39 @@ class qtopensesame(QtGui.QMainWindow):
 				self.update_dialog( \
 					_("... and is sorry to say that the attempt to check for updates has failed. Please make sure that you are connected to the internet and try again later. If this problem persists, please visit <a href='http://www.cogsci.nl/opensesame'>http://www.cogsci.nl/opensesame</a> for more information."))
 			return
-
-		try:
-			if len(self.version.split("-")) == 2:
-				cv = float(self.version.split("-")[0]) - 0.01 + 0.00001 * int(self.version.split("-")[1][3:])
-				debug.msg("you are running a pre-release version, identifying as %s" \
-					% cv)
-			else:
-				cv = float(self.version)
-		except:
-			debug.msg("version is not numeric")
-			return
-
-		if mrv > float(cv):
+		
+		# The most recent version as downloaded is always a float. Therefore, we
+		# must convert the various possible version numbers to analogous floats.
+		# We do this by dividing each subversion number by 100. The only
+		# exception is that prereleases should be counted as older than stable
+		# releases, so for pre-release we substract one bugfix version.
+		# 0.27			->	0.27.0.0			->	0.27
+		# 0.27.1 		-> 	0.27.1.0			->	0.2701
+		# 0.27~pre1		->	0.27.0.1 - .0001	-> 	0.269901
+		# 0.27.1~pre1	->	0.27.1.1 - .0001	-> 	0.270001		
+		v = self.version	
+		l = v.split("~pre")
+		if len(l) == 2:
+			lastSubVer = l[1]
+			v = l[0]		
+			ver = -.0001
+		else:
+			lastSubVer = 0
+			ver = .0
+		lvl = 0
+		fct = .01
+		for subVer in v.split('.') + [lastSubVer]:
+			try:
+				_subVer = int(subVer)
+			except:
+				debug.msg('Failed to process version segment %s' % subVer, \
+					reason='warning')
+				return
+			ver += fct**lvl * _subVer
+			lvl += 1			
+		debug.msg('identifying as version %s' % ver)
+		debug.msg('latest stable version is %s' % mrv)
+		if mrv > ver:
 			self.update_dialog( \
 				_("... and is happy to report that a new version of OpenSesame (%s) is available at <a href='http://www.cogsci.nl/opensesame'>http://www.cogsci.nl/opensesame</a>!") % mrv)
 		else:
@@ -620,7 +645,7 @@ class qtopensesame(QtGui.QMainWindow):
 
 		w = self.ui.tabwidget.get_widget('__preferences__')
 		if w != None:
-			w.set_controls()	
+			w.set_controls()
 
 	def show_text_in_toolbar(self):
 
@@ -751,20 +776,6 @@ class qtopensesame(QtGui.QMainWindow):
 		subprocess.Popen(cmd)
 		QtCore.QCoreApplication.quit()
 
-	def close(self):
-
-		"""Cleanly close opensesame"""
-
-		resp = QtGui.QMessageBox.question(self.ui.centralwidget, _("Quit?"), \
-			_("Are you sure you want to quit OpenSesame?"), \
-			QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
-		if resp == QtGui.QMessageBox.No:
-			return
-		libopensesame.experiment.clean_up(debug.enabled)
-		self.save_unsaved_changes()
-		self.save_state()
-		QtCore.QCoreApplication.quit()
-
 	def closeEvent(self, e):
 
 		"""
@@ -772,30 +783,37 @@ class qtopensesame(QtGui.QMainWindow):
 		is clicked
 
 		Arguments:
-		e -- the closeEvent
+		e -- the closeEvent or a bool
 		"""
 
 		if debug.enabled or self.devmode:
 			libopensesame.experiment.clean_up(debug.enabled)
 			self.save_state()
-			e.accept()
+			if isinstance(e, bool):
+				QtCore.QCoreApplication.quit()
+			else:
+				e.accept()
 			return
 
 		resp = QtGui.QMessageBox.question(self.ui.centralwidget, _("Quit?"), \
 			_("Are you sure you want to quit OpenSesame?"), \
 			QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
 		if resp == QtGui.QMessageBox.No:
-			e.ignore()
+			if not isinstance(e, bool):
+				e.ignore()
 		else:
 			libopensesame.experiment.clean_up(debug.enabled)
 			self.save_unsaved_changes()
 			self.save_state()
-			e.accept()
+			if isinstance(e, bool):
+				QtCore.QCoreApplication.quit()
+			else:
+				e.accept()
 
 	def update_recent_files(self):
 
 		"""Recreate the list with recent documents"""
-		
+
 		from libqtopensesame.actions import recent_action
 
 		# Add the current path to the front of the list
@@ -849,20 +867,16 @@ class qtopensesame(QtGui.QMainWindow):
 
 		path = unicode(path)
 		self.set_status("Opening ...")
-		self.ui.tabwidget.close_all()		
+		self.ui.tabwidget.close_all()
 		cfg.file_dialog_path = os.path.dirname(path)
 
 		try:
 			exp = experiment.experiment(self, "Experiment", path)
-		except Exception as e:			
+		except Exception as e:
 			self.experiment.notify( \
 				_("<b>Error:</b> Failed to open '%s'<br /><b>Description:</b> %s<br /><br />Make sure that the file is in .opensesame or .opensesame.tar.gz format. If you should be able to open this file, but can't, please go to http://www.cogsci.nl/opensesame to find out how to recover your experiment and file a bug report.") \
 				% (path, e))
-			# Print the traceback in debug mode
-			if debug.enabled:
-				l = traceback.format_exc(e).split("\n")
-				for r in l:
-					print r
+			self.print_debug_window(e)
 			return
 
 		self.experiment = exp
@@ -907,7 +921,7 @@ class qtopensesame(QtGui.QMainWindow):
 		# Get ready, generate the script and see if the script can be
 		# re-parsed. In debug mode any errors are not caught. Otherwise. a
 		# neat exception is thrown.
-		if self.experiment.debug:
+		if debug.enabled:
 			self.get_ready()
 			script = self.experiment.to_string()
 			experiment.experiment(self, "Experiment", script)
@@ -926,9 +940,9 @@ class qtopensesame(QtGui.QMainWindow):
 				return
 
 		# Try to save the experiment if it doesn't exist already
-		if self.experiment.debug:
+		if debug.enabled:
 			resp = self.experiment.save(self.current_path, overwrite=True)
-			self.set_status(_("Saved as %s") % self.current_path)			
+			self.set_status(_("Saved as %s") % self.current_path)
 		else:
 			try:
 				resp = self.experiment.save(self.current_path, overwrite=True)
@@ -954,21 +968,21 @@ class qtopensesame(QtGui.QMainWindow):
 			cfg.file_dialog_path = os.path.join(self.home_folder, self.experiment.sanitize( \
 				self.experiment.title, strict=True, allow_vars=False))
 		else:
-			cfg.file_dialog_path = self.current_path		
+			cfg.file_dialog_path = self.current_path
 		path, file_type = QtGui.QFileDialog.getSaveFileNameAndFilter( \
 			self.ui.centralwidget, _("Save file as ..."), directory= \
 			cfg.file_dialog_path, filter=self.file_type_filter)
-							
+
 		if path != None and path != "":
 			path = unicode(path)
 			cfg.file_dialog_path = os.path.dirname(path)
-			
+
 			# If the extension has not been explicitly typed in, set it based
 			# on the selected filter and, if no filter has been set, based on
 			# whether there is content in the file pool
 			if path[-18:].lower() != ".opensesame.tar.gz" and \
 				path[-11:].lower() != ".opensesame":
-				debug.msg("automagically determing file type")			
+				debug.msg("automagically determing file type")
 				if "(*.opensesame)" in file_type:
 					path += ".opensesame"
 				elif "(*.opensesame.tar.gz)" in file_type:
@@ -978,7 +992,7 @@ class qtopensesame(QtGui.QMainWindow):
 				else:
 					path += ".opensesame.tar.gz"
 				debug.msg(path)
-					
+
 			self.current_path = path
 			self.save_file()
 
@@ -1052,7 +1066,7 @@ class qtopensesame(QtGui.QMainWindow):
 			return
 
 		self.experiment = tmp
-		self.refresh()			
+		self.refresh()
 
 	def build_item_list(self, name=None):
 
@@ -1148,6 +1162,25 @@ class qtopensesame(QtGui.QMainWindow):
 						debug.msg("'%s' did something" % item)
 						redo = True
 						break
+						
+	def print_debug_window(self, msg):
+		
+		"""
+		Prints a message to the debug window.
+		
+		Arguments:
+		msg		--	An object to print to the debug window. If it's an exception
+					than a full traceback will be printed.
+		"""
+		
+		from libqtopensesame.widgets import pyterm				
+		out = pyterm.output_buffer(self.ui.edit_stdout)
+		if isinstance(msg, Exception):
+			import traceback
+			for s in traceback.format_exc(msg).split('\n'):
+				out.write(s)
+		else:
+			out.write(self.experiment.unistr(msg))
 
 	def call_opensesamerun(self, exp):
 
@@ -1162,7 +1195,8 @@ class qtopensesame(QtGui.QMainWindow):
 
 		# Temporary file for the standard output and experiment
 		stdout = tempfile.mktemp(suffix = ".stdout")
-		path = tempfile.mktemp(suffix = ".opensesame.tar.gz")
+		path = os.path.join(exp.experiment_path, \
+			'.opensesamerun-tmp.opensesame.tar.gz')
 		exp.save(path, True)
 		debug.msg("experiment saved as '%s'" % path)
 
@@ -1175,7 +1209,8 @@ class qtopensesame(QtGui.QMainWindow):
 		else:
 			cmd = config.get_config('opensesamerun_exec').split()
 
-		cmd += [path, "--logfile=%s" % exp.logfile, "--subject=%s" % exp.subject_nr]
+		cmd += [path, "--logfile=%s" % exp.logfile, "--subject=%s" \
+			% exp.subject_nr]
 
 		if debug.enabled:
 			cmd.append("--debug")
@@ -1278,7 +1313,7 @@ class qtopensesame(QtGui.QMainWindow):
 			exp.set("subject_nr", 999)
 			exp.set("subject_parity", "odd")
 			logfile = os.path.join(config.get_config('default_logfile_folder'), \
-				config.get_config('quick_run_logfile'))				
+				config.get_config('quick_run_logfile'))
 
 		else:
 
@@ -1363,17 +1398,17 @@ class qtopensesame(QtGui.QMainWindow):
 				# Report the error
 				if isinstance(e, libopensesame.exceptions.runtime_error):
 					self.experiment.notify(e)
-				elif isinstance(e, openexp.exceptions.openexp_error):
-					print unicode(e)
+					self.print_debug_window(e)
+				elif isinstance(e, openexp.exceptions.openexp_error):					
 					self.experiment.notify( \
 						_("<b>Error</b>: OpenExp error<br /><b>Description</b>: %s") \
 						% e)
+					self.print_debug_window(e)
 				else:
 					self.experiment.notify( \
 						_("An unexpected error occurred, which was not caught by OpenSesame. This should not happen! Message:<br/><b>%s</b>") \
 						% self.experiment.unistr(e))
-					for s in traceback.format_exc(e).split("\n"):
-						print s
+					self.print_debug_window(e)
 
 		# Undo the standard output rerouting
 		sys.stdout = sys.__stdout__
@@ -1393,11 +1428,11 @@ class qtopensesame(QtGui.QMainWindow):
 		"""Runs the experiment in a window"""
 
 		self.run_experiment(fullscreen=False)
-		
+
 	def run_quick(self):
-		
+
 		"""Run the experiment without asking for subject nr and logfile"""
-		
+
 		self.run_experiment(fullscreen=False, quick=True)
 
 	def refresh(self, changed_item=None, refresh_edit=True, \
@@ -1502,9 +1537,9 @@ class qtopensesame(QtGui.QMainWindow):
 		Arguments:
 		menu -- a QMenu instance
 		"""
-		
+
 		from libqtopensesame.actions import plugin_action
-		
+
 		cat_menu = {}
 		for plugin in libopensesame.plugins.list_plugins():
 			debug.msg("found plugin '%s'" % plugin)
@@ -1574,7 +1609,7 @@ class qtopensesame(QtGui.QMainWindow):
 				name = self.experiment.sanitize(unicode(name), strict=True, \
 					allow_vars=False)
 				if name not in self.experiment.items:
-					break				
+					break
 			if not ok:
 				return None
 			name = unicode(name)
@@ -1798,7 +1833,7 @@ class qtopensesame(QtGui.QMainWindow):
 
 		from libqtopensesame.widgets import draggables
 
-		debug.msg("dropping from toolbar")
+		debug.msg(u'dropping from toolbar')
 
 		# Determine the drop target
 		if draggables.drop_target == None:
@@ -1806,7 +1841,7 @@ class qtopensesame(QtGui.QMainWindow):
 		target, index, select = draggables.drop_target
 
 		# Create a new item and return if it fails
-		if type(add_func) != str:
+		if not isinstance(add_func, basestring):
 			new_item = add_func(False, parent=target)
 		else:
 			new_item = self.add_item(add_func, False)
@@ -1814,11 +1849,11 @@ class qtopensesame(QtGui.QMainWindow):
 			self.refresh(target)
 			return
 
-		if target == "__start__":
-			self.experiment.set("start", new_item)
+		if target == u'__start__':
+			self.experiment.set(u'start', new_item)
 		else:
 			self.experiment.items[target].items.insert(index, (new_item, \
-				"always"))
+				u'always'))
 
 		self.refresh(target)
 		if select:
